summaryrefslogtreecommitdiffstats
path: root/libkdepim/infoextension.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdepim/infoextension.h')
-rw-r--r--libkdepim/infoextension.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/libkdepim/infoextension.h b/libkdepim/infoextension.h
index 343f71720..392178f5a 100644
--- a/libkdepim/infoextension.h
+++ b/libkdepim/infoextension.h
@@ -44,10 +44,10 @@ namespace KParts
/**
* Constucts an InfoExtension.
*
* @param tqparent The tqparent widget.
* @param name The name of the class.
**/
- InfoExtension( KParts::ReadOnlyPart *tqparent, const char* name);
+ InfoExtension( KParts::ReadOnlyPart *parent, const char* name);
~InfoExtension();
private:
@@ -44,10 +44,10 @@ namespace KParts
* Constucts an InfoExtension.
*
- * @param tqparent The tqparent widget.
+ * @param parent The parent widget.
* @param name The name of the class.
**/